// subPackageMarketing/page/pages/scratch/scratch.js
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util')
import Scratch from '../../components/scratch/scratch.js'
import { Integer } from '../../../../utils/integerDigitalConvertion'
const app = getApp();
const defaultWelcomeImage = 'https://img3.bigaka.com/test/1002/202004/20200413/10021096c17c-fbc6-49a8-a53c-8bbf0502df44.jpg';
const defaultScratchCover = 'https://img3.bigaka.com/test/1002/202004/20200413/100208b0fbce-b73d-4af9-bd74-47d1ea5311d5.png';
wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    loading : true,
    btnName : '开始刮奖',
    leftNum : 0,
    activityId : null,
    activityInfo : {},
    hasNoActivity : true,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    
    this.data.activityId = options.id;
    if(this.data.activityId){
      this.getActivityInfo();
    }

    this.handleShare(options);
  },

  //处理分享数据信息
  handleShare(options){
    //有触点切是用户分享的才调用接口
    if(options.t && options.s == 'share'){
      let t = Integer.digit(options.t, 64, 10);
      wxService.post('/marketing/tentacleContent/queryTentacleContentById', { id: t }).then((res) => {
        if(res){
          let data = res.data.data ? res.data.data : null;
          if(data){
            // //判断打开着是不是自己
            let currentLogginUser = wx.getStorageSync('_baseUserInfo');
            data.tentacleType = data.type;

            // this.markShareRecords(currentLogginUser.memberId,this.data.activityId,data);
            // return ;

            if(!currentLogginUser){
              let memberId = null;
              this.markShareRecords(memberId,this.data.activityId,data);
            }
            else{
              let curLoginMemberId = currentLogginUser.memberId;
              let memberId = data.tentacleId;
              if(curLoginMemberId != memberId){ // 不是自己打开的分享链接时才调用分享成功的接口 防止自己刷次数
                this.markShareRecords(curLoginMemberId,this.data.activityId,data);
              }
            }
          }
        }
      });
    }
  },

  //记录分享数据
  markShareRecords(memberId = null,activityId,tentacleContent){
    wxService.post(`/marketing/lottery/shareRecord`,{
      activityId : activityId,
      memberId : memberId,
      tentacleContent : tentacleContent,
    }).then(res => {});
  },

  //查看规则
  onTapToRule(){
    let ruleImg = this.data.activityInfo.desc;
    if(!ruleImg){
      wx.showToast({
        title: '商家暂未设置规则说明',
        icon : 'none'
      });
      return ;
    }

    wx.navigateTo({
      url: '/subPackageMarketing/page/pages/scratchRule/scratchRule?rule=' + encodeURIComponent(ruleImg),
    });
  },

  //获取活动详情
  getActivityInfo(){
    wxService.get(`/marketing/lotterySet/findById?id=${this.data.activityId}`).then(res => {
      let {result , data} = res.data;
      if(result == 0 && data){
          this.data.activityInfo = data;
          this.data.activityInfo.path = 'subPackageMarketing/page/pages/scratch/scratch?id=' + this.data.activityInfo.id + '&s=share';
          this.data.activityInfo.welcomeImage = this.data.activityInfo.welcomeImage ? this.data.activityInfo.welcomeImage : defaultWelcomeImage;
          this.setData({
            activityInfo : this.data.activityInfo,
            hasNoActivity : false,
          });

          //生成触点
          this.shareGenerateContent();
          this.getUserCanScratchCount();
          //初始化刮刮卡信息
          this.initScratch();
      }
      else{
        wx.showToast({
          title: '未获取到活动信息',
          icon : 'none'
        });
        this.setData({
          loading : false,
          hasNoActivity : true,
        })
      }
    })
  },

  //获取当前用户可刮刮卡次数
  getUserCanScratchCount(){
    if(!this.data.currentHasUserInfo) {
      //初始化刮刮卡信息
      return;
    } ;
    const { memberId } = wx.getStorageSync('_baseUserInfo');
    let activityId = this.data.activityInfo.id;
    wxService.post(`/marketing/lottery/getLotteryNumber?activityId=${activityId}&memberId=${memberId}`).then(res => {
      if(res){
        let count = res.data.data ? res.data.data : 0;
        this.data.leftNum = count;
        this.setData({
          leftNum : this.data.leftNum,
        });
        //这里不判断数量是否没有了，都初始化挂版
        this.scratch.start();
      }
    })
  },

  //开始刮奖或重新刮奖
  onClickStartScratch(){
    if(this.data.leftNum <= 0){
      wx.showToast({
        title: '对不起,您没有刮奖机会了',
        icon : 'none'
      });
      return;
    }

    if(this.data.btnName == '开始刮奖'){
      this.scratch.start();
      this.setData({
        btnName : '再刮一次'
      });
    }
    else{
      this.scratch.restart();
    }
  },

  //初始化刮刮卡
  initScratch(){
    let width = app.globalData.systemInfo.screenWidth;
    let self = this;
    this.scratch = new Scratch(this, {
        canvasWidth: width*0.9 - 30,
        canvasHeight: 130,
        imageResource: self.data.activityInfo.backColor ?  self.data.activityInfo.backColor : defaultScratchCover,
        r: 18,
        awardTxt: '多刮一点，再多刮一点😊😜',
        awardTxtColor: '#333333',
        awardTxtFontSize: '22px',
        callback: () => {
            if(self.data.leftNum > 0){
              self.getAwardInfo();
            }
            else{
              //对不起，你的刮奖次数已用完,您可以去商城逛逛~
              self.scratch.setAwardText('对不起，您的刮奖次数不足啦😭!');
              wx.showModal({
                title: '刮奖数不足提示',
                content: '对不起，您的刮奖次数已用完,您可以去商城逛逛~',
                showCancel: true,
                cancelText: '取消',
                confirmText: '去逛逛',
                confirmColor: '#cb3c3c',
                success: function (modalRes) {
                  if(modalRes.confirm){
                    wx.reLaunch({
                      url: '/pages/userCenter/userCenter',
                    });
                  }
                }
              });
            }
        },
        initOkCallBack(){
          self.setData({
            loading : false
          })
        },
    });
  },

  //抽奖
  getAwardInfo(){
    const { memberId } = wx.getStorageSync('_baseUserInfo');
    let activityId = this.data.activityInfo.id;
    let self = this;
    wxService.get(`/marketing/lottery/lottery?activityId=${activityId}&memberId=${memberId}`).then(res => {
      if(res){
        if(res.data.result == 0){
          if(!res.data.data){
            this.scratch.setAwardText(this.data.activityInfo.notWinning);
            wx.showModal({
              title: '刮奖结果提示',
              content: this.data.activityInfo.notWinning ? this.data.activityInfo.notWinning : '很遗憾，您未中奖',
              showCancel: true,
              cancelText: '关闭',
              confirmText: '再刮一次',
              confirmColor: '#cb3c3c',
              success: function (modalRes) {
                self.scratch.restart();
              }
            });
          }
          else{
            let data = res.data.data;
            if(data.thePrizeType == 1){
              //中的积分
              let integral = data.integral;
              this.scratch.setAwardText(`恭喜您中了${integral}积分`);
              wx.showModal({
                title: '刮奖结果提示',
                content: `恭喜您中了${integral}积分`,
                showCancel: true,
                cancelText: '关闭',
                confirmText: '再刮一次',
                confirmColor: '#cb3c3c',
                success: function (modalRes) {
                  self.scratch.restart();
                }
              });
            }
            else if(data.thePrizeType == 2){
              //中的是优惠券
              let couponList = data.couponList ;
              let names = couponList.map(item => {
                return item.couponName;
              });
              this.scratch.setAwardText(`恭喜您中了优惠券：“${names.join(',')}”`);
              wx.showModal({
                title: '刮奖结果提示',
                content: `恭喜您中了优惠券：“${names.join(',')}”`,
                showCancel: true,
                cancelText: '关闭',
                confirmText: '再刮一次',
                confirmColor: '#cb3c3c',
                success: function (modalRes) {
                  self.scratch.restart();
                }
              });
            }
          }
        }
      }

      this.getUserCanScratchCount();
    });
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {

  },

  //分享生成触点
  shareGenerateContent(){
    //判断是否登录了
    if(!this.data.currentHasUserInfo){
      return ;
    }

    let content = {
      title: this.data.activityInfo.name,
      id: this.data.activityInfo.id,
      url: this.data.activityInfo.sharePhotos
    }
    let tentacleInfo = {
      content: JSON.stringify(content),
      contentId: this.data.activityInfo.id,
      contentType: app.globalData.contants.SHARE_TYPE.TRANSMIT, //内容类型 
      title: this.data.activityInfo.name, //标题
      type: 3// 1:门店,2:员工(暂时不做),3:会员,4:第三方外部渠道,5:智能营销
    }

    wxService.getTentacleContent(tentacleInfo).then(res => {
      if (res && res.id) {
        let tentacleId = res.id;
        let inner_id = Integer.digit(this.data.activityInfo.id, 10, 64);
        let inner_tentacleId = Integer.digit(tentacleId, 10, 64);
        var path = 'subPackageMarketing/page/pages/scratch/scratch' + '?i=' + inner_id + '&t=' + inner_tentacleId + '&s=share';
        this.data.activityInfo.path = path;
      }
    });

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function (res) {
    if (res.from == 'menu') {
      return {
        title: this.data.activityInfo.shareTitle,
        path: this.data.activityInfo.path,
        imageUrl: this.data.activityInfo.sharePhotos
      }
    }
  }
});